@@ -17,8 +17,10 @@ globalVariables(c(".",
                   "inner_join",
                   "mutate",
                   "select",
-                  "select_",
                   "rename",
+                  "quo",
+                  "UQ",
+                  "quo_name",
                   "from_row",
                   "from_col",
                   "to_row",
